@@ -155,6 +155,8 @@ ruleInduction.apriori <- function(x, transactions, confidence = 0.8,
         ##	with support == min support in x
         minSupport <-  min(quality(x)$support) - 1/length(transactions)
 
+        ### suppress maxlen warnings
+        suppressWarnings(
         rules <- apriori(transactions,  parameter = list(
                 support = minSupport,
                 confidence = confidence, 
@@ -162,7 +164,8 @@ ruleInduction.apriori <- function(x, transactions, confidence = 0.8,
                 minlen = min(isetsSize), 
                 maxlen = max(isetsSize)),
             control = list(verbose = verbose))
-
+        )
+        
         ## find rules which were generated by the itemsets
         if (verbose) cat(paste("starting to filter", length(rules), "rules.\n"))
         take <- !is.na(match(items(rules), items(x)))
