@@ -1,6 +1,5 @@
 /*----------------------------------------------------------------------
-The code for apriori and eclat were obtained from
-            http://fuzzy.cs.uni-magdeburg.de/~borgelt/
+The code for apriori and eclat were obtained from http://www.borgelt.net/
 
 and are copyrighted by 1996-2003 Christian Borgelt
 
@@ -454,7 +453,30 @@ void frequentItem(ARparameter *param, INPUT *in)
 	  param->maxlen = maxcnt;            /* to the maximum set size */
   /* --- check item subsets --- */
   if (param->verbose) Rprintf("checking subsets of size 1");
-  while (ist_height(istree) < param->maxlen) {
+  
+  /* while (ist_height(istree) < param->maxlen) { */
+  while (1) {
+    /* R check for C-C to interupt execution */
+    /* Note: This creates a memory leak. I would like to call cleanup() */
+    R_CheckUserInterrupt();
+    
+    /* Check if we reach the max. transaction size */
+    if(ist_height(istree) >= maxcnt) break;
+    
+    /* Check if we run into limits */
+    if(ist_height(istree) >= param->maxlen){
+      /* if (param->verbose) Rprintf(" *stopping (maxlen reached)*"); */
+      Rf_warning("Mining stopped (maxlen reached). Only patterns up to a length of %d returned!", param->maxlen);
+      break;
+    }
+    
+    if(SEC_SINCE(t) > param->maxtime) {
+      /* if (param->verbose) Rprintf(" *stopping (time limit)*"); */
+      Rf_warning("Mining stopped (time limit reached). Only patterns up to a length of %d returned!", 
+        ist_height(istree));
+      break;
+    }
+    
     if (param->filter != 0) {          /* if to filter w.r.t. item usage, */
       i = ist_check(istree, apps);     /* check current item usage */
       if (i < param->maxlen) param->maxlen = i;      /* update the maximum size */
@@ -463,10 +485,8 @@ void frequentItem(ARparameter *param, INPUT *in)
     k = ist_addlvl(istree);     /* while max. height is not reached, */
     if (k <  0) {cleanup(); error(msgs(E_NOMEM));}  /* add a level to the item set tree */
     if (k != 0) break;          /* if no level was added, abort */
-    if (param->verbose) Rprintf(" %d", ist_height(istree));
     
-    /* R check for C-C to interupt execution */
-    R_CheckUserInterrupt();
+    if (param->verbose) Rprintf(" %d", ist_height(istree));
     
     if (tatree) {               /* if a transaction tree was created */
       if (((param->filter < 0)         /* if to filter w.r.t. item usage */
@@ -499,7 +519,7 @@ void frequentItem(ARparameter *param, INPUT *in)
     else {
       in->index = 0;
       for (maxcnt = 0; (i = is_read_in(itemset, in)) == 0; ) {
-	if (param->filter != 0)        /* (re)read the transactions and */
+	      if (param->filter != 0)        /* (re)read the transactions and */
           is_filter(itemset, apps);  /* remove unnecessary items */
         k = is_tsize(itemset);  /* update the maximum size */
         if (k > maxcnt) maxcnt = k;  /* of a transaction */
@@ -510,6 +530,7 @@ void frequentItem(ARparameter *param, INPUT *in)
         param->maxlen = maxcnt;        /* according to the max. t.a. size */
     }                           /* (may be smaller than before) */
   }                             /* clear the file variable */
+
   if (param->verbose) Rprintf(" done [%.2fs].\n", SEC_SINCE(t));
 
   /* --- filter found item sets --- */
@@ -566,6 +587,11 @@ void createRules(ISTREE *istree, ARparameter *param) {
   size1 = ruleset->rnb;
   if (target <= TT_CLSET) {     /* if to find frequent item sets */
     for (n = 0; 1; ) {          /* extract item sets from the tree */
+     
+     /* R check for C-C to interupt execution */
+     /* Note: This creates a memory leak. I would like to call cleanup() */
+     R_CheckUserInterrupt(); 
+      
       k = ist_set(istree, set, &supp, &conf);
       if (k <= 0) break;        /* get the next frequent item set */
       if (supp > param->smax) continue;/* check against maximal support */
@@ -614,6 +640,11 @@ void createRules(ISTREE *istree, ARparameter *param) {
   } 
   else if (target == TT_RULE) { /* if to find association rules, */
     for (n = 0; 1; ) {          /* extract rules from tree */
+      
+	    /* R check for C-C to interupt execution */
+	    /* Note: This creates a memory leak. I would like to call cleanup() */
+	    R_CheckUserInterrupt();
+      
       k = ist_rule(istree, set, &supp, &conf, &lftval, &minval);
       if (k <= 0) break;        /* get the next association rule */
       if (supp > param->smax) continue;/* check against maximal support */
@@ -692,6 +723,11 @@ void createRules(ISTREE *istree, ARparameter *param) {
   }
   else {                        /* if to find association hyperedges */
     for (n = 0; 1; ) {          /* extract hyperedges from tree */
+	      
+	   /* R check for C-C to interupt execution */
+	   /* Note: This creates a memory leak. I would like to call cleanup() */
+	   R_CheckUserInterrupt(); 
+      
       k = ist_hedge(istree, set, &supp, &conf);
       if (k <= 0) break;        /* get the next hyperedge */
       if (supp > param->smax) continue;/* check against maximal support */
@@ -958,6 +994,7 @@ SEXP rapriori(SEXP x, SEXP y, SEXP dim, SEXP parms, SEXP control, SEXP app, SEXP
 
 	param.minlen = *INTEGER(GET_SLOT(parms, install("minlen")));   /* minimal rule length 'm'*/
 	maxlen = param.maxlen = *INTEGER(GET_SLOT(parms, install("maxlen")));   /* maximal rule length 'n'*/  
+	param.maxtime = *REAL(GET_SLOT(parms, install("maxtime")));      /* maximal time allowed in seconds*/
 	param.sort = *INTEGER(GET_SLOT(control, install("sort")));     /* flag for item sorting and recoding 'q'*/
 
 	param.rsdef = *LOGICAL(GET_SLOT(parms, install("originalSupport")));      /* rule support definition 'o'*/
@@ -1056,8 +1093,8 @@ SEXP rapriori(SEXP x, SEXP y, SEXP dim, SEXP parms, SEXP control, SEXP app, SEXP
 	in.ind = INTEGER(x);
 	in.index = 0;
 	in.tnb = length(x)-1;
-  	frequentItem(&param, &in);	
-  	createRules(istree, &param);
+  frequentItem(&param, &in);	
+  createRules(istree, &param);
 	ruleset->cnt = is_cnt(itemset);
 	ruleset->tacnt = in.tnb;
  	SET_SLOT(parms, install("maxlen"), allocVector(INTSXP, 1)); 
